pub struct BlockLootContext<'a> {
world: &'a Arc<World>,
pos: BlockPos,
entity: Option<&'a dyn Entity>,
tool: Option<&'a ItemStack>,
luck: f32,
}Expand description
Live parameters used to resolve a block’s loot.
This is the Steel counterpart to vanilla’s block LootParams. Behaviors can
override loot generation while retaining the original tool, entity, luck,
and position when delegating to another block state.
Fields
world: &'a Arc<World>pos: BlockPosentity: Option<&'a dyn Entity>tool: Option<&'a ItemStack>luck: f32Implementations
Sourceimpl<'a> BlockLootContext<'a>
impl<'a> BlockLootContext<'a>
Sourcepub const fn new(world: &'a Arc<World>, pos: BlockPos) -> Self
pub const fn new(world: &'a Arc<World>, pos: BlockPos) -> Self
Creates a no-tool block loot context.
Sourcepub const fn with_entity(self, entity: Option<&'a dyn Entity>) -> Self
pub const fn with_entity(self, entity: Option<&'a dyn Entity>) -> Self
Adds the entity responsible for destroying the block.
Sourcepub const fn with_tool(self, tool: &'a ItemStack) -> Self
pub const fn with_tool(self, tool: &'a ItemStack) -> Self
Adds the tool used to destroy the block.
Sourcepub fn get_drops(&self, state: BlockStateId) -> Vec<ItemStack>
pub fn get_drops(&self, state: BlockStateId) -> Vec<ItemStack>
Resolves loot for another state with the same vanilla loot parameters.
pub(crate) const fn entity(&self) -> Option<&'a dyn Entity>
pub(crate) const fn tool(&self) -> Option<&'a ItemStack>
pub(crate) const fn luck(&self) -> f32